==> haskell-djinn-ghc-0.0.2.3-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-djinn-ghc.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: djinn-ghc
version: 0.0.2.3
id: djinn-ghc-0.0.2.3-947yhGg7hKE789fA4Fikvr
key: djinn-ghc-0.0.2.3-947yhGg7hKE789fA4Fikvr
license: BSD3
maintainer: trupill@gmail.com
synopsis: Generate Haskell code from a type. Bridge from Djinn to GHC API.
description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is the bridge from djinn-lib to GHC API.
category: Language
author: Alejandro Serrano
exposed: True
indefinite: False
exposed-modules:
    Djinn.GHC
abi: 8f6c58fbf94f31325f9931f7950f2108
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/djinn-ghc-0.0.2.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/djinn-ghc-0.0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/djinn-ghc-0.0.2.3
hs-libraries: HSdjinn-ghc-0.0.2.3-947yhGg7hKE789fA4Fikvr
depends:
    base-4.10.1.0 mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH ghc-8.2.2
    containers-0.5.10.2 transformers-0.5.2.0
    djinn-lib-0.0.1.2-6pjk7lYM0S6Ey0Bano1HWg
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=a1f89647d7228db4bf59b7aaec52e888
             ghc-8.2.2=a5b8ae61d881d53b10e55af3743c7814
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             djinn-lib-0.0.1.2-6pjk7lYM0S6Ey0Bano1HWg=6c0acc936b774d24e9e0b28a9f98217f
             async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
haddock-interfaces: /usr/share/doc/haskell-djinn-ghc/html/djinn-ghc.haddock
haddock-html: /usr/share/doc/haskell-djinn-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-djinn-ghc-0.0.2.3-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-djinn-ghc.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: djinn-ghc
version: 0.0.2.3
id: djinn-ghc-0.0.2.3-1tlBFbTotX09eYhZgjenmq
key: djinn-ghc-0.0.2.3-1tlBFbTotX09eYhZgjenmq
license: BSD3
maintainer: trupill@gmail.com
synopsis: Generate Haskell code from a type. Bridge from Djinn to GHC API.
description:
    Djinn uses an theorem prover for intuitionistic propositional logic
    to generate a Haskell expression when given a type.
    This is the bridge from djinn-lib to GHC API.
category: Language
author: Alejandro Serrano
exposed: True
indefinite: False
exposed-modules:
    Djinn.GHC
abi: a8a072ef0593369e2ba37160bfa83e3f
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/djinn-ghc-0.0.2.3
library-dirs: /usr/lib/ghc-8.2.2/site-local/djinn-ghc-0.0.2.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/djinn-ghc-0.0.2.3
hs-libraries: HSdjinn-ghc-0.0.2.3-1tlBFbTotX09eYhZgjenmq
depends:
    base-4.10.1.0 mtl-2.2.2-8XubxMJDT8QLsstvlNotkc ghc-8.2.2
    containers-0.5.10.2 transformers-0.5.2.0
    djinn-lib-0.0.1.2-HlTwlVjN6i6FtLSYll9plq
    async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             mtl-2.2.2-8XubxMJDT8QLsstvlNotkc=9d788b97813db77c2d48570ade6e04a9
             ghc-8.2.2=a5b8ae61d881d53b10e55af3743c7814
             containers-0.5.10.2=0f9db0d1b935cacba444aac19f4cb54d
             transformers-0.5.2.0=b5dee110a615d751493b7ce1c6f95946
             djinn-lib-0.0.1.2-HlTwlVjN6i6FtLSYll9plq=366fca8c28b86508d4750c5a3c8e2dcd
             async-2.1.1.1-8ROwjo1yVqvF3cWHtq6DEd=987aeec331bd3d9d85b408736a8805c6
haddock-interfaces: /usr/share/doc/haskell-djinn-ghc/html/djinn-ghc.haddock
haddock-html: /usr/share/doc/haskell-djinn-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
